function aws = tbx_cfg_aws4SPM
% Configuration file for toolbox 'aws4SPM'
%_______________________________________________________________________
% Copyright (C) 2014 WIAS Berlin
%
% To get information about this toolbox:
% http://www.wias-berlin.de/software/imaging/aws4SPM.jsp
%
% Karsten Tabelow
% $Id: tbx_cfg_aws4SPM.m 3960 2010-06-30 17:41:24Z ged $

% ---------------------------------------------------------------------
% spm_file SPM.mat
% ---------------------------------------------------------------------
    spm_file         = cfg_files;
    spm_file.tag     = 'spm_file';
    spm_file.name    = 'Select SPM.mat';
    spm_file.help    = {'Select the SPM.mat file with the estimated GLM.'};
    spm_file.filter  = 'SPM.mat';
    spm_file.ufilter = '.*';
    spm_file.num     = [1 1];
% ---------------------------------------------------------------------
% hmax Maximal Bandwidth for aws
% ---------------------------------------------------------------------
    hmax        = cfg_entry;
    hmax.tag     = 'hmax';
    hmax.name    = 'hmax';
    hmax.help    = {'Maximal bandwidth. '};
    hmax.strtype = 'e';
    hmax.num     = [1 1];
    hmax.val    = {3};

% ---------------------------------------------------------------------
% ladjust for aws
% ---------------------------------------------------------------------
    lambda        = cfg_entry;
    lambda.tag     = 'lambda';
    lambda.name    = 'lambda';
    lambda.help    = {'Adaptation bandwidth. '};
    lambda.strtype = 'e';
    lambda.num     = [1 1];
    lambda.val    = {10};

% ---------------------------------------------------------------------
% fwhm Bias FWHM
% ---------------------------------------------------------------------
%     kernel       = cfg_menu;
%     kernel.tag     = 'kernel';
%     kernel.name    = 'Location kernel';
%     kernel.help    = {'Choice of location kernel'};
%     kernel.val     = {2};
%     kernel.labels = {'Uniform'
%                      'Epanechnikov'
%                      'Biweight'
%                      'Triweight'               
%                      'Gauss'}';
%     kernel.values = {0 1 2 3 4};

% ---------------------------------------------------------------------
% hdw High-Dimensional Warping
% ---------------------------------------------------------------------
    aws         = cfg_exbranch;
    aws.tag     = 'aws';
    aws.name    = 'AWS4SPM';
    aws.val     = {spm_file hmax lambda};
    aws.help    = {'This toolbox implements structural adaptive smoothing for SPM.'}';
    aws.prog    = @spm_local_aws;
     aws.vout     = @vout_aws;
    

%======================================================================
function out = spm_local_aws(job)

  % access by job.spm_file, job.hmax, job.ladjust
  if ~isdeployed, addpath(fullfile(spm('Dir'),'toolbox','aws4SPM')); end

  [out.hReg,out.xSPM,out.SPM] = spm_smooth_gamma(job.spm_file, job.hmax, job.lambda);
  out.TabDat = spm_list('List',out.xSPM,out.hReg);
  
  assignin('base','hReg',out.hReg);
  assignin('base','xSPM',out.xSPM);
  assignin('base','SPM',out.SPM);
  assignin('base','TabDat',out.TabDat);


function dep = vout_aws(job)
  dep(1)            = cfg_dep;
  dep(1).sname      = 'xSPM struct';
  dep(1).src_output = substruct('.','xSPM');
  dep(1).tgt_spec   = cfg_findspec({{'strtype','e'}});
  dep(2)            = cfg_dep;
  dep(2).sname      = 'SPM struct';
  dep(2).src_output = substruct('.','SPM');
  dep(2).tgt_spec   = cfg_findspec({{'strtype','e'}});








